# LLVMPY Meow!

llvmpym is a python library that provides LLVM binding. It bases on the LLVM C API.  

This project is still in a very early stage  

## Documentation

[link](https://ziqi-yang.github.io/llvmpym/)  

The online static HTML document utilize GitHub Pages service. Although [Read the Docs](https://docs.readthedocs.io/en/stable/) provides document version functionality, it is not chosen since the build of
llvmpym's document needs to have stub files generated, which requires a CI environment.

